const vscode = require("vscode");
const { AISidebarProvider } = require('./src/utils/AISidebarProvider');
const LLMSelectorPanel = require('./src/settings/panels/llmSelector');
const SecureSettingsManager = require('./src/settings/secureSettingsManager');
const { RepoTracker } = require('./src/utils/RepoTracker');

async function activate(context) {
    // Initialize secure settings manager first
    const settingsManager = new SecureSettingsManager(context);
    await settingsManager.initialize();

    // Initialize RepoTracker
    const repoTracker = new RepoTracker();
    await repoTracker.initialize();
    
    // Set up git watcher
    const gitWatcher = await repoTracker.watchGitChanges();
    context.subscriptions.push(gitWatcher);

    // Initialize providers with secure settings manager and repoTracker
    const provider = new AISidebarProvider(context.extensionUri, settingsManager, repoTracker);
    
    // Register the sidebar provider
    context.subscriptions.push(
        vscode.window.registerWebviewViewProvider('C4B3Rstudios.93m1n1gpt', provider)
    );

    // Register the LLM selector command
    let llmSelectorCommand = vscode.commands.registerCommand(
        'C4B3Rstudios.93m1n1gpt.showLLMSelector', 
        () => {
            const llmSelector = new LLMSelectorPanel(context.extensionUri, settingsManager);
            llmSelector.createOrShow(vscode.ViewColumn.One);
        }
    );

    // Register the main command
    let mainCommand = vscode.commands.registerCommand('C4B3Rstudios.93m1n1gpt', () => {
        vscode.window.showInformationMessage('93m1n1gpt is now active!');
    });

    context.subscriptions.push(llmSelectorCommand, mainCommand);
}

function deactivate() { }

module.exports = {
    activate,
    deactivate
};