// ChatService.js
const vscode = require("vscode")
const { ChatOllama } = require("@langchain/ollama");
const { PromptTemplate } = require("@langchain/core/prompts");

class ChatService {
    constructor(settingsManager) {
        this._settingsManager = settingsManager;
    }

    async handleChatMessage(webviewView, userMessage, messageHistory, markdownRenderer, repoTracker) {
        messageHistory.push({ role: "user", content: userMessage });

        const config = this._getConfig();
        const contextInfo = await this._getContextInfo(repoTracker);
        const chat = this._createChatInstance(config);

        await this._streamResponse(chat, messageHistory, webviewView, markdownRenderer);
    }

    _getConfig() {
        const config = vscode.workspace.getConfiguration('93m1n1gpt');
        return {
            model: config.get('selectedModel') || "llama2:13b",
            apiUrl: config.get('apiUrl') || "http://localhost:11434"
        };
    }

    async _getContextInfo(repoTracker) {
        const gitStatus = await repoTracker.getGitStatus();
        return gitStatus ? 
            `\nCurrent git branch: ${gitStatus.branch}\nLast commit: ${gitStatus.lastCommit}` : '';
    }

    _createChatInstance(config) {
        return new ChatOllama({
            model: config.model,
            baseUrl: config.apiUrl,
            temperature: 0.6,
            topP: 0.9,
            topK: 40,
            streaming: true
        });
    }

    async _streamResponse(chat, messageHistory, webviewView, markdownRenderer) {
        let currentStreamedText = "";
        const stream = await chat.stream([...messageHistory]);

        for await (const chunk of stream) {
            currentStreamedText += chunk.content;
            const formattedMarkdown = markdownRenderer.render(currentStreamedText);
            webviewView.webview.postMessage({
                command: "updateBotMessage",
                html: formattedMarkdown
            });
        }

        messageHistory.push({ role: "assistant", content: currentStreamedText });
    }
}

module.exports = { ChatService };
