// MarkdownRenderer.js
const MarkdownIt = require("markdown-it");
const hljs = require("highlight.js");

class MarkdownRenderer {
    constructor() {
        this.md = new MarkdownIt({
            highlight: this._highlightCode.bind(this),
            html: true,
            linkify: true
        });
    }

    _highlightCode(str, lang) {
        let highlighted;
        try {
            highlighted = lang && hljs.getLanguage(lang) 
                ? hljs.highlight(str, { language: lang }).value 
                : this.md.utils.escapeHtml(str);
        } catch (err) {
            console.error("Syntax highlighting error:", err);
            highlighted = this.md.utils.escapeHtml(str);
        }

        const escapedCode = this.md.utils.escapeHtml(str);
        return this._wrapCodeBlock(escapedCode, highlighted, lang);
    }

    _wrapCodeBlock(escapedCode, highlighted, lang) {
        return `
            <div class="code-block-wrapper">
                <div class="code-block-header">
                    <span class="code-language">${lang || 'text'}</span>
                    <div class="code-block-buttons">
                        <button class="code-button copy-button" data-code="${escapedCode}">Copy</button>
                        <button class="code-button insert-button" data-code="${escapedCode}">Insert</button>
                    </div>
                </div>
                <pre class="hljs"><code class="language-${lang || 'text'}">${highlighted}</code></pre>
            </div>`;
    }

    render(text) {
        return this.md.render(text);
    }
}

module.exports = { MarkdownRenderer };
