// UIManager.js
const vscode = require("vscode");
const { styles } = require("../webview/sidebar/styles");
const { scripts } = require("../webview/sidebar/scripts");

class UIManager {
    constructor(extensionUri) {
        this._extensionUri = extensionUri;
    }

    initializeWebview(webviewView, extensionUri) {
        webviewView.webview.options = {
            enableScripts: true,
            localResourceRoots: [extensionUri]
        };

        webviewView.webview.html = this._getWebviewContent();
    }

    handleCopyCode(text) {
        vscode.env.clipboard.writeText(text);
        vscode.window.showInformationMessage('Code copied to clipboard!');
    }

    handleInsertCode(code) {
        const editor = vscode.window.activeTextEditor;
        if (editor) {
            editor.edit(editBuilder => {
                editBuilder.insert(editor.selection.active, code);
            });
        }
    }

    _getWebviewContent() {
        return `
            <!DOCTYPE html>
            <html>
                <head>
                    <style>${styles}</style>
                </head>
                <body>
                    <div id="gitStatus"></div>
                    <div id="chatContainer" class="chat-container">
                        <div id="messageContainer" class="message-container"></div>
                        <div class="input-container">
                            <input 
                                type="text" 
                                id="promptInput" 
                                placeholder="Type a message..."
                                class="prompt-input"
                            />
                            <button id="sendButton" class="send-button">Send</button>
                        </div>
                    </div>
                    <script>${scripts}</script>
                </body>
            </html>
        `;
    }
}

module.exports = { UIManager };