// scripts.js
exports.scripts = /*javascript*/`
    let fileTree = [];
    let gitStatus = null;
    const vscode = acquireVsCodeApi();

    // Handle file reference suggestions
    promptInput.addEventListener('input', (e) => {
        const text = e.target.value;
        const lastAtSign = text.lastIndexOf('@');
        if (lastAtSign !== -1) {
            const prefix = text.substring(lastAtSign + 1);
            vscode.postMessage({
                command: 'getFileReferences',
                prefix: prefix
            });
        }
    });

    // Handle git status updates
    window.addEventListener('message', event => {
        const message = event.data;
        switch (message.command) {
            case 'updateGitStatus':
                gitStatus = message.gitStatus;
                updateGitStatusDisplay();
                break;
            case 'updateFileTree':
                fileTree = message.fileTree;
                break;
            case 'fileReferenceSuggestions':
                showFileReferenceSuggestions(message.suggestions);
                break;
            case 'updateBotMessage':
                updateChatDisplay(message.html);
                break;
        }
    });

    function updateGitStatusDisplay() {
        if (!gitStatus) return;
        
        const statusEl = document.getElementById('gitStatus');
        if (statusEl) {
            statusEl.innerHTML = \`
                <div class="git-info">
                    <span>Branch: \${gitStatus.branch}</span>
                    <span>Last commit: \${gitStatus.lastCommit}</span>
                </div>
            \`;
        }
    }

    function showFileReferenceSuggestions(suggestions) {
        let suggestionsDiv = document.getElementById('suggestions');
        if (!suggestionsDiv) {
            suggestionsDiv = document.createElement('div');
            suggestionsDiv.id = 'suggestions';
            suggestionsDiv.className = 'suggestions';
            document.body.appendChild(suggestionsDiv);
        }

        if (suggestions.length === 0) {
            suggestionsDiv.style.display = 'none';
            return;
        }

        const rect = promptInput.getBoundingClientRect();
        suggestionsDiv.style.position = 'absolute';
        suggestionsDiv.style.left = rect.left + 'px';
        suggestionsDiv.style.top = (rect.bottom + 5) + 'px';
        suggestionsDiv.style.display = 'block';

        suggestionsDiv.innerHTML = suggestions.map(file => \`
            <div class="suggestion" data-path="\${file.path}">
                \${file.path}
            </div>
        \`).join('');

        suggestionsDiv.querySelectorAll('.suggestion').forEach(el => {
            el.addEventListener('click', () => {
                const path = el.dataset.path;
                const cursorPos = promptInput.selectionStart;
                const textBeforeCursor = promptInput.value.substring(0, cursorPos);
                const lastAtSign = textBeforeCursor.lastIndexOf('@');
                const textAfterCursor = promptInput.value.substring(cursorPos);
                
                promptInput.value = textBeforeCursor.substring(0, lastAtSign) + 
                    '@' + path + ':' + textAfterCursor;
                suggestionsDiv.style.display = 'none';
                promptInput.focus();
            });
        });
    }

    function updateChatDisplay(html) {
        const chatContainer = document.getElementById('chatContainer');
        if (chatContainer) {
            chatContainer.innerHTML = html;
            chatContainer.scrollTop = chatContainer.scrollHeight;
        }
    }

    // Handle code actions
    document.addEventListener('click', (e) => {
        if (e.target.classList.contains('copy-button')) {
            vscode.postMessage({
                command: 'copyCode',
                text: e.target.dataset.code
            });
        } else if (e.target.classList.contains('insert-button')) {
            vscode.postMessage({
                command: 'insertCode',
                text: e.target.dataset.code
            });
        }

        // Hide suggestions when clicking outside
        const suggestionsDiv = document.getElementById('suggestions');
        if (suggestionsDiv && !suggestionsDiv.contains(e.target) && e.target !== promptInput) {
            suggestionsDiv.style.display = 'none';
        }
    });
`;
